#
# spec file for package perl-Net-Telnet
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Net-Telnet
Version:        3.04
Release:        1.25
%define cpan_name Net-Telnet
Summary:        interact with TELNET port or other TCP ports
License:        GPL-1.0+ or Artistic-1.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Net-Telnet/
Source:         http://www.cpan.org/authors/id/J/JR/JROGERS/%{cpan_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
Net::Telnet allows you to make client connections to a TCP port and do
network I/O, especially to a port using the TELNET protocol. Simple I/O
methods such as print, get, and getline are provided. More sophisticated
interactive features are provided because connecting to a TELNET port
ultimately means communicating with a program designed for human
interaction. These interactive features include the ability to specify a
time-out and to wait for patterns to appear in the input stream, such as
the prompt from a shell. IPv6 support is available when using perl 5.14 or
later (see 'family()'.

Other reasons to use this module than strictly with a TELNET port are:

* *

  You're not familiar with sockets and you want a simple way to make client
  connections to TCP services.

* *

  You want to be able to specify your own time-out while connecting,
  reading, or writing.

* *

  You're communicating with an interactive program at the other end of some
  socket or pipe and you want to wait for certain patterns to appear.

Here's an example that prints who's logged-on to a remote host. In addition
to a username and password, you must also know the user's shell prompt,
which for this example is '"bash$ "'

    use Net::Telnet ();
    $t = new Net::Telnet (Timeout => 10,
                          Prompt => '/bash\$ $/');
    $t->open($host);
    $t->login($username, $passwd);
    @lines = $t->cmd("who");
    print @lines;

See the *EXAMPLES* section below for more examples.

Usage questions should be directed to the perlmonks.org discussion group.
Bugs can be viewed or reported at cpan.org on the Net::Telnet page.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc ChangeLog README

%changelog
* Sat Jun  8 2013 coolo@suse.com
- updated to 3.04
  * Telnet.pm (open family sockfamily): Added IPv6
    support.  It is enabled using the method/parameter
    family() and the installed Socket package version is
    1.94+ (which corresponds with perl 5.14+).
  * Telnet.pm (peerhost peerport sockhost sockport):
    New methods to support IPv6, because the inherited
    ones from IO::Socket::INET don't.
  * Telnet.pm (open localhost localfamily): New
    methods and open() parameters for binding to a local
    network interface.
  * Telnet.pm (dump_log, input_log, option_log, output_log): Fixed
    so they turn off logging when passed an empty string arg.
  * Telnet.pm (_fillbuf _put): Fixed to use
    Errno::EINTR, when possible, to test for an
    interrupted select(), sysread(), or syswrite().  The
    test for $! =~ /^interrupted doesn't work when LANG
    is not English.
  * Telnet.pm (dump_log, input_log, option_log, output_log): Fixed
    so they take a bare filehandle.
* Wed Feb 27 2013 coolo@suse.com
- update license to new format
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Thu Jun 19 2003 mjancar@suse.cz
- fix filelist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Fri Dec 20 2002 prehak@suse.cz
- updated to version 3.03
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Wed Aug 22 2001 rvasice@suse.cz
- initial package release (version 3.02)
